==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/PodSecurityPolicySelfSubjectReviewBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class PodSecurityPolicySelfSubjectReviewBuilder extends io.fabric8.openshift.api.model.PodSecurityPolicySelfSubjectReviewFluentImpl<io.fabric8.openshift.api.model.PodSecurityPolicySelfSubjectReviewBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.PodSecurityPolicySelfSubjectReview,io.fabric8.openshift.api.model.PodSecurityPolicySelfSubjectReviewBuilder>{
  public PodSecurityPolicySelfSubjectReviewBuilder() {
    this(false);
  }
  public PodSecurityPolicySelfSubjectReviewBuilder(java.lang.Boolean validationEnabled) {
    this(new PodSecurityPolicySelfSubjectReview(), validationEnabled);
  }
  public PodSecurityPolicySelfSubjectReviewBuilder(io.fabric8.openshift.api.model.PodSecurityPolicySelfSubjectReviewFluent<?> fluent) {
    this(fluent, false);
  }
  public PodSecurityPolicySelfSubjectReviewBuilder(io.fabric8.openshift.api.model.PodSecurityPolicySelfSubjectReviewFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new PodSecurityPolicySelfSubjectReview(), validationEnabled);
  }
  public PodSecurityPolicySelfSubjectReviewBuilder(io.fabric8.openshift.api.model.PodSecurityPolicySelfSubjectReviewFluent<?> fluent,io.fabric8.openshift.api.model.PodSecurityPolicySelfSubjectReview instance) {
    this(fluent, instance, false);
  }
  public PodSecurityPolicySelfSubjectReviewBuilder(io.fabric8.openshift.api.model.PodSecurityPolicySelfSubjectReviewFluent<?> fluent,io.fabric8.openshift.api.model.PodSecurityPolicySelfSubjectReview instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  public PodSecurityPolicySelfSubjectReviewBuilder(io.fabric8.openshift.api.model.PodSecurityPolicySelfSubjectReview instance) {
    this(instance,false);
  }
  public PodSecurityPolicySelfSubjectReviewBuilder(io.fabric8.openshift.api.model.PodSecurityPolicySelfSubjectReview instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.PodSecurityPolicySelfSubjectReviewFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.PodSecurityPolicySelfSubjectReview build() {
    PodSecurityPolicySelfSubjectReview buildable = new PodSecurityPolicySelfSubjectReview(fluent.getApiVersion(),fluent.getKind(),fluent.getSpec(),fluent.getStatus());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PodSecurityPolicySelfSubjectReviewBuilder that = (PodSecurityPolicySelfSubjectReviewBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/PodSecurityPolicySelfSubjectReviewBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class PodSecurityPolicySelfSubjectReviewBuilder extends io.fabric8.openshift.api.model.PodSecurityPolicySelfSubjectReviewFluentImpl<io.fabric8.openshift.api.model.PodSecurityPolicySelfSubjectReviewBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.PodSecurityPolicySelfSubjectReview,io.fabric8.openshift.api.model.PodSecurityPolicySelfSubjectReviewBuilder>{
  public PodSecurityPolicySelfSubjectReviewBuilder() {
    this(false);
  }
  public PodSecurityPolicySelfSubjectReviewBuilder(java.lang.Boolean validationEnabled) {
    this(new PodSecurityPolicySelfSubjectReview(), validationEnabled);
  }
  public PodSecurityPolicySelfSubjectReviewBuilder(io.fabric8.openshift.api.model.PodSecurityPolicySelfSubjectReviewFluent<?> fluent) {
    this(fluent, false);
  }
  public PodSecurityPolicySelfSubjectReviewBuilder(io.fabric8.openshift.api.model.PodSecurityPolicySelfSubjectReviewFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new PodSecurityPolicySelfSubjectReview(), validationEnabled);
  }
  public PodSecurityPolicySelfSubjectReviewBuilder(io.fabric8.openshift.api.model.PodSecurityPolicySelfSubjectReviewFluent<?> fluent,io.fabric8.openshift.api.model.PodSecurityPolicySelfSubjectReview instance) {
    this(fluent, instance, false);
  }
  public PodSecurityPolicySelfSubjectReviewBuilder(io.fabric8.openshift.api.model.PodSecurityPolicySelfSubjectReviewFluent<?> fluent,io.fabric8.openshift.api.model.PodSecurityPolicySelfSubjectReview instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public PodSecurityPolicySelfSubjectReviewBuilder(io.fabric8.openshift.api.model.PodSecurityPolicySelfSubjectReview instance) {
    this(instance,false);
  }
  public PodSecurityPolicySelfSubjectReviewBuilder(io.fabric8.openshift.api.model.PodSecurityPolicySelfSubjectReview instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.PodSecurityPolicySelfSubjectReviewFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.PodSecurityPolicySelfSubjectReview build() {
    PodSecurityPolicySelfSubjectReview buildable = new PodSecurityPolicySelfSubjectReview(fluent.getApiVersion(),fluent.getKind(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PodSecurityPolicySelfSubjectReviewBuilder that = (PodSecurityPolicySelfSubjectReviewBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
